@@ -1,11 +1,17 @@
-VERSION = '0.1.1'
+VERSION = '0.1.3'
 PACKAGE_NAME = 'reptile-network'
 
 REQUIREMENTS = [
-    'cupy==8.4.0',
     'idx2numpy==1.2.3',
     'numpy==1.20.1',
 ]
 
+EXCLUDES = [
+    '__tests__',
+    'tests.py'
+]
+
 AUTHOR = 'sTonKs'
 AUTHOR_EMAIL = 'kisel@internet.ru' # Временно, пока не зарегаем нормальный домен и не сделаем нашу почту корповую
+
+DESCRIPTION = 'Краткое описание coming soon...'
